OnyxCamera class

the onyx camera utility class.

Constructors

OnyxCamera()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOnyxMethodChannel() → MethodChannel
Get the method channel used by the onyx Plugin
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

options ↔ OnyxOptions
The onyx configuration options.
getter/setter pair
results ↔ OnyxResults
the fingerprint results.
getter/setter pair
state → OnyxState
The Onyx State object. Add a listener for state change events.
no setter

Static Methods

configureOnyx() → Future<void>
Configures onyx with the values in the OnyxCamera.options class.
startOnyx() → Future<void>
Starts onyx.